@@ -4,7 +4,7 @@ import shutil
 import requests
 from pathlib import Path
 
-from .trace import MANAGE, REQUIREMENTS, WSGI, URLS, SETTINGS, VIEWS, MODELS, ADMIN, README
+from .trace import MANAGE, REQUIREMENTS, WSGI, URLS, SETTINGS, VIEWS, MODELS, ADMIN, README, APP_URLS
 
 
 def generate(terminal_token, project_token, *args):
@@ -48,10 +48,10 @@ def generate(terminal_token, project_token, *args):
                         ff.write(f[1])
         
         # generate apps
-        # removed ('urls.py', APP_URLS(app)) because of beta
+        # removed ('urls.py', APP_URLS(app)), ('models.py', MODELS(app)), ('admin.py', ADMIN(app)), ('apps.py', f"from django.apps import AppConfig\n\n\nclass AppConfig(AppConfig):\n\tname = '{app.get('name')}'"), ('tests.py', 'from django.test import TestCase'), because of beta
         for app in res.get('apps'):
             file_extensions = {
-                '': [('__init__.py', ''), ('models.py', MODELS(app)), ('admin.py', ADMIN(app)), ('apps.py', f"from django.apps import AppConfig\n\n\nclass AppConfig(AppConfig):\n\tname = '{app.get('name')}'"), ('tests.py', 'from django.test import TestCase'), ('views.py', VIEWS(app))],
+                '': [('__init__.py', ''), ('views.py', VIEWS(app))],
                 'migrations/': [('__init__.py', '')],
             }
             for k, v in file_extensions.items():
@@ -77,30 +77,41 @@ def sync(terminal_token, project_token, *args):
                             'project_token': project_token,
                         })).json()
     
-    if not os.path.exists('projects'):
-        os.mkdir('projects')
+    import clixdev
+    if not os.path.exists(clixdev.__path__ + '/projects'):
+        os.mkdir(clixdev.__path__ + '/projects')
+        os.mkdir(clixdev.__path__ + '/projects/migrations')
     
-    if not os.path.exists('projects/'):
-        os.mkdir('projects/')
-
-    f = open('projects/' + '/__init__.py', 'w')
+    f = open(clixdev.__path__ + '/projects' + '/__init__.py', 'w')
+    f.write("")
+    f.close()
+    
+    f = open(clixdev.__path__ + '/projects/migrations' + '/__init__.py', 'w')
     f.write("")
     f.close()
 
     # write urls based on res -> api.clix.dev
-    f = open('projects/' + '/_urls.py', 'w')
+    f = open(clixdev.__path__ + '/projects' + '/urls.py', 'w')
     f.write(APP_URLS(res.get('apps')[0]))
     f.close()
 
-    f = open('projects/' + '/_models.py', 'w')
+    f = open(clixdev.__path__ + '/projects' + '/models.py', 'w')
     f.write(MODELS(res.get('apps')[0]))
     f.close()
 
-    # not sure about views yet
-    f = open('projects/' + '/_validators.txt', 'w')
-    f.write(json.dumps("""[{"name": "API", "base_url": "api", "endpoints": [{"misc": {"endpoint_id": "ae0937d9-95e4-4ea1-9ff5-76312209e948", "is_draft": false, "token": "rcxxday", "name": "Get all users", "description": "The description", "base_url": "api"}, "request": {"method": "GET", "host": "localhost", "uri": "users/all"}, "headers": {"authorization": true, "body": {"0": ["auth-token", "str"]}}, "params": {"0": ["d", "uuid"]}, "body": {"type": "none", "payload": {}}, "response": {"code": "200", "message": "OK"}}], "models": [{"table_name": "User", "fields": {"0": ["D372D1", "id", "UUIDField", null, null, false, false, false, true, true], "1": ["F8B9D7", "f_name", "CharField", null, null, true, true, true, false, false], "2": ["D0BA20", "l_name", "CharField", null, null, true, true, true, false, false], "3": ["21341C", "created_at", "DateTimeField", null, null, false, false, true, false, false]}}]}]"""))
+    f = open(clixdev.__path__ + '/projects' + '/apps.py', 'w')
+    f.write("""from django.apps import AppConfig
+
+class AppConfig(AppConfig):
+        name = 'clixdev.projects'
+""")
     f.close()
 
+    # not sure about views yet
+    # f = open('projects/' + '/_validators.txt', 'w')
+    # f.write(json.dumps("""[{"name": "API", "base_url": "api", "endpoints": [{"misc": {"endpoint_id": "ae0937d9-95e4-4ea1-9ff5-76312209e948", "is_draft": false, "token": "rcxxday", "name": "Get all users", "description": "The description", "base_url": "api"}, "request": {"method": "GET", "host": "localhost", "uri": "users/all"}, "headers": {"authorization": true, "body": {"0": ["auth-token", "str"]}}, "params": {"0": ["d", "uuid"]}, "body": {"type": "none", "payload": {}}, "response": {"code": "200", "message": "OK"}}], "models": [{"table_name": "User", "fields": {"0": ["D372D1", "id", "UUIDField", null, null, false, false, false, true, true], "1": ["F8B9D7", "f_name", "CharField", null, null, true, true, true, false, false], "2": ["D0BA20", "l_name", "CharField", null, null, true, true, true, false, false], "3": ["21341C", "created_at", "DateTimeField", null, null, false, false, true, false, false]}}]}]"""))
+    # f.close()
+
     # f = open('/usr/local/.clix/projects.txt', 'w')
     # f.write(json.dumps("""[{"name": "API", "base_url": "api", "endpoints": [{"misc": {"endpoint_id": "ae0937d9-95e4-4ea1-9ff5-76312209e948", "is_draft": false, "token": "rcxxday", "name": "Get all users", "description": "The description", "base_url": "api"}, "request": {"method": "GET", "host": "localhost", "uri": "users/all"}, "headers": {"authorization": true, "body": {"0": ["auth-token", "str"]}}, "params": {"0": ["d", "uuid"]}, "body": {"type": "none", "payload": {}}, "response": {"code": "200", "message": "OK"}}], "models": [{"table_name": "User", "fields": {"0": ["D372D1", "id", "UUIDField", null, null, false, false, false, true, true], "1": ["F8B9D7", "f_name", "CharField", null, null, true, true, true, false, false], "2": ["D0BA20", "l_name", "CharField", null, null, true, true, true, false, false], "3": ["21341C", "created_at", "DateTimeField", null, null, false, false, true, false, false]}}]}]"""))
     # f.close()
